%--------------------------------------------------------------------------   
%  Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko
%  Beispiel 10.2, Rekonstruktion CT
%  WARNUNUG:
%  Dieses Skript nutzt einige Funktionen aus dem Paket 
%  Regulariation Tools von P.C. Hansen
%  https://de.mathworks.com/matlabcentral/fileexchange/52-regtools   
%   Author: Yury Luchko, Date:   9/2019
%--------------------------------------------------------------------------


% 

clear; close all

% Fr Matlab und Octave werden unterschiedliche Bilddimensionen festgelegt
if exist('OCTAVE_VERSIO','builtin') > 0
    pix = 40;
else
    pix = 60;
end

P = phantom('Modified Shepp-Logan',pix);
k = length(P);
f = P(:); 

% Koeffizientenmatrix A mit der Matlab-Funktion "tomo.m" 
% aus dem Matlab-Paket "Regularisation Tools" berechnen
[A,~,~] = tomo(k, 1); 

% Dimension und Singuaerwertzerlegung der Matrix A 
[m,n]   = size(A); [U,s,V] = csvd(full(A));

% Das direkte CT-Problem frs Testbild loesen
b = A * f ;

% Berechnete Lsung b stoeren
stoer   = rand(m,1)*0.001; b_stoer = b + stoer;

% Das gestoerte Problem ohne Regularisierung loesen
f_stoer  = A\b_stoer ;

% Das Testbild und die Loesung visualisieren
figure('name','Originalbild')
imagesc(reshape(f,pix,pix)); colormap(gray)
figure('name','Gestoertes Bild')
imagesc(reshape(f_stoer,pix,pix)); colormap(gray)

% Regularisierungsparameter lambda setzen
lambda = [1,0.1,1.e-2,1.e-3,1.e-4,1.e-5,1.e-6];

% Das nach Tikhonov regularisierte Problem lsen
f_lambda = tikhonov(U,s,V,b_stoer,lambda);

% Graphische Darstellung der 
% regularisierten Lsungen des gestrten Problems
for i = 1:length(lambda)
figure('name', ['Tikhonovsche Regularisierung mit Lambda = ' num2str(lambda(i))]); 
imagesc(reshape(f_lambda(:,i),pix,pix)), colormap(gray) 
end

% L-Kurve wird nur in Matlab erstellt
if exist ('OCTAVE_VERSION', 'builtin') > 0
  return
else
      
% Graphische Darstellung der L-Kurve und Berechnung
% des optimalen Wertes des Regularisierungsparameters lambda
lambda_opt = l_curve(U,s,b_stoer,'Tikh')

% Graphische Darstellung der 
% regularisierten Loesungen des gestoerten Problems
% fuer den optimalen Wert des Regularisierungsparameters lambda
f_lambda_opt = tikhonov(U,s,V,b_stoer,lambda_opt);
figure('name', ['Tikhonovsche Regularisierung mit Lambda = ' num2str(lambda_opt)]); 
imagesc(reshape(f_lambda_opt,pix,pix)), colormap(gray) 
end