%--------------------------------------------------------------------------   
%  Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko
%  Beispiel 10.2, Rekonstruktion CT
%  WARNUNUG:
%  Dieses Skript nutzt einige Funktionen aus dem Paket 
%  Regulariation Tools von P.C. Hansen
%  https://de.mathworks.com/matlabcentral/fileexchange/52-regtools  
%           tomo() und l_curve()
%   Author: Yury Luchko, Date:   9/2019
%--------------------------------------------------------------------------

clear; close all

% Testbild als Vektor f 
f = [0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 ...
     0 0 0 0 1 1 0 0 0 0 0 0 0 0 1 1 0 0 0 0 ...
     0 1 1 1 1 1 1 1 1 0 0 1 1 1 1 1 1 1 1 0 ...
     0 0 0 0 1 1 0 0 0 0 0 0 0 0 1 1 0 0 0 0 ... 
     0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0]';  
     
% Matrix A mit tome.m aus dem Paket Reg.Tools
[A,~,~] = tomo(10); 

% Dimension und Singulaerwertzerlegung von A 
[m,n]   = size(A); [U,s,V] = csvd(full(A));

% Direktes CT-Problem
b = A * f ;

% Stoerung der Loesung b
stoer   = rand(m,1)*0.1; b_stoer = b + stoer;

% Das gestoerte Problem ohne Regularisierung
f_stoer  = A\b_stoer;

% Visualisierung
figure, imagesc(reshape(f,10,10)); colormap(gray)
figure, imagesc(reshape(f_stoer,10,10)); colormap(gray)

% Regularisierungsparameter
lambda = [1,0.1,1.e-2,1.e-3,1.e-4,1.e-5,1.e-6];

% Tikhonov-Regularisierung
f_lambda = zeros(n,length(lambda));
for i = 1:length(lambda)
    for k = 1:n
        f_lambda(:,i) = f_lambda(:,i) + ...
(s(k)^2/(s(k)^2+lambda(i)))*((U(:,k)'*b_stoer)/s(k))*V(:,k);
    end
    
    % Visualisierung
    figure, imagesc(reshape(f_lambda(:,i),10,10));
    colormap(gray) 
end

% L-Kurve wird nur in Matlab erstellt
if exist ('OCTAVE_VERSION', 'builtin') > 0
  return;
else
 
% Optimaler Wert von lambda und die L-Kurve 
% mit l_curve.m aus dem Paket Reg.Tools
lambda_opt = l_curve(U,s,b_stoer,'Tikh');

% Regularisierung mit dem optimalen Wert von lambda
f_opt = zeros(n,1);
for k = 1:n
    f_opt = f_opt + ...
(s(k)^2/(s(k)^2+lambda_opt))*((U(:,k)'*b_stoer)/s(k))*V(:,k);
end
    
% Visualisierung
figure, imagesc(reshape(f_opt,10,10)), colormap(gray) 
end