%-------------------------------------------------------------------------- 
%  Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko
%  Basketball Freiwurf, Listing 2.10
%     
%   function [thetaOpt, vOpt, fehler] ...
%               = besteWurfbahnOptimierung(hS, w, thetaIni, vIni)
%     Eingabeparameter:
%        hS:         Groesse des Werfers   [m]
%        w:          Gewicht bei der Mehrzieloptimierung
%        thetaIni:   Startwert Abwurfwinkel [grad]
%        vIni:       Startwert Abwurfgeschwindigkeit [m]
%       
%     Ausgabeparameter:
%        thetaOpt:    Optimaler Abwurfwinkel 
%        vOpt:        Optimale Abwurfgeschwindigkeit
%        fehler:      Wert der Zielfunktion im Optimum
%                                     
%     Author: Frank Hausser
%     Date:   8/2009
%--------------------------------------------------------------------------

function [thetaOpt, vOpt, fehler] ...
          = besteWurfbahnOptimierung(hS,w,thetaIni, vIni)

options = optimset('fminsearch');
opts    = optimset(options,'MaxFunEvals', 10000,'MaxIter',10000);

[x,fval] = fminsearch( @(x) zielFunktion(x,hS,w), ...
                      [thetaIni, vIni],opts);
thetaOpt = x(1);  vOpt = x(2); fehler = -fval;
end

%- - - - - - - - - zielFunktion - - - - - - - - - - - -
function fehler = zielFunktion(x,hS,w)
[thetaMinMax,vMinMax] = fehlerWurfbahn(x(1),x(2),hS);
if isempty(thetaMinMax)
    fehler      = 10;    % Strafterm
else
    fehler = -min( [ (x(1) - thetaMinMax(1))/x(1), ...
                     (thetaMinMax(2) - x(1))/x(1), ...
                      w * (x(2) - vMinMax(1))/x(2), ...
                      w * (vMinMax(2)- x(2))/x(2)] );
end
end


