%--------------------------------------------------------------------------
%  Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko, 2010  %
%     Polarplot kontinuierlicher Spiralen mit Radius r(phi) = a*f(phi)    %
%       mit a > 0, f > 0 monoton steigend                                 % 
%--------------------------------------------------------------------------

close all;
clear all;

%-------------- Berechnung ------------------------------------------------
%  diskrete Menge von Punkten (phi_i, r_i) auf den Spiralen

n    = 5;                       % Anzahl Umdrehungen
phi  = linspace(0,2*n*pi,1000); % diskrete Winkel

% Archimedische Spirale
a      = 1/2/pi;
rArch  = a*phi;                 % Radien

% Logarithmische Spirale
k      = 0.1;
a      = n/exp(k*n*2*pi);
rLog   = a*exp(k*phi);          % Radien

% Fermatsche Spirale
a       = n/sqrt(n*2*pi);
rFermat = a*sqrt(phi);          % Radien

%-------------- Plot der Spiralen -----------------------------------------
set(0,'DefaultAxesColorOrder',[0,0,0])

%-- Archimedische Spirale
subplot(1,3,1);
h = polar(phi,rArch);
set(h,'LineWidth',2)
title('Archimedisch');

%-- Logarithmische Spirale
subplot(1,3,2);
h = polar(phi,rLog);
set(h,'LineWidth',2)
title('Logarithmisch');

%-- Fermatsche Spirale
subplot(1,3,3);
h = polar(phi,rFermat);
set(h,'LineWidth',2)
title('Fermat');




