%--------------------------------------------------------------------------
%  Mathematische Modellierung mit MATLAB und Octave
%          F. Hausser und Y. Luchko, 2019
%      Autor: Frank Hausser, 6/2019
%--------------------------------------------------------------------------


%%   Erzeuge ein Drei-Cluster-Problem oder lade Daten
numCluster = 3;
if LOADDATA == false
    m1 = 5;
    m2 = 5%8;
    m3 = 3%10;
    m4 = 0%10;
    X1 = 2*randn(m1,2) + [-3, 3];
    X2 = 2*randn(m2,2) + [-3, -3];
    X3 = 2*randn(m3,2) + [3, 0];
    X4 = 2*randn(m4,2) ;
    X = [X1; X2; X3; X4];
    
    % Initialisierung der Zentroiden
    [m,n] = size(X);
    initialCentroids = X(randperm(m, numCluster), :);
else
    load kmeansDaten;
end

%% Berechne Clustering, unterschiedliche Anzahl Iterationen
for maxIter = 1:6
    [idx, centroids, J] = kmeansEinfach(X, numCluster, maxIter-1, initialCentroids);
    centroids
    
    fig = figure(maxIter);
    plot(X(idx==1, 1), X(idx==1, 2), 'o', 'MarkerSize', 8, ...
        'MarkerFaceColor', 'k', 'LineWidth', 1.5);
    hold on;
    plot(X(idx==2, 1), X(idx==2, 2), '>', 'MarkerSize', 8, ...
        'MarkerFaceColor', [0.75 0.75 0.75], 'LineWidth', 1.5);
    plot(X(idx==3, 1), X(idx==3, 2), 's', 'MarkerSize', 8, 'LineWidth', 1.5);
    plot (centroids(:, 1), centroids(:, 2), 'kx', 'Markersize', 15, 'LineWidth', 1.5);
    hold off
    set(gca, 'FontSize', 16);
    axis equal
    
    set(gca, 'xtick',[],'ytick',[], 'xlim',[-8 8],'ylim',[-8 8]);
end

