function [c, Mue,  J] =  kmeansEinfach(X, numCluster, maxIter, initialCentroids)
%   kmeansEinfach(X, numCluster, initialCentroids)
%   Input: 
%         X: m x n - Matrix mit m Datenpunkten mit n Merkmalen
%         numCluster: Anzahl Cluster       
%   Output:
%         c: m x 1 - Matrix, enthlt Cluster jedes Datenpunktes
%         Mue: numCluster x n: Zentroide 
%         J:   Kostenfunktion
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%  Mathematische Modellierung mit MATLAB und Octave                        
%          F. Hausser und Y. Luchko, 2019  
%      Autor: Frank Hausser, 6/2019                                                                   
%--------------------------------------------------------------------------

k     = numCluster;
m     = size(X, 1);

if nargin < 4
    Mue = X(randperm(m, numCluster), :);
else
    Mue = initialCentroids;
end

if nargin < 3
    maxIter = 20;
end

d2 = zeros(m,k);
J  = zeros(1,maxIter);

for it = 1:maxIter
    %% (1) Zuordnung der Datenpunkte zu Clustern (zu Zentroiden)
    for j = 1:k
        d2(:,j) = sum( (X - Mue(j,:) ).^2, 2);
    end
    [d, c] = min(d2, [], 2);
    
    % Auswertung der Kostenfunktion (zur Konvergenzueberpruefung)
    J(it) = d'*d/(2*m);
    
    %% (2) Neue Zentroide als Schwerpunkte der Cluster
    for j = 1:k
        clusterGroesse = size(X(c==j,:), 1);
        if clusterGroesse ~= 0
            Mue(j,:) = sum( X(c==j,:) )/clusterGroesse;
        else
            Mue(j,:) = X(randperm(m, 1),:);
        end
    end
end

%% Finale  Zuordnung der Datenpunkte zu den Clustern
for j = 1:k
    d2(:,j) = sum( (X - Mue(j,:) ).^2, 2);
end
[d, c] = min(d2, [], 2);

% Auswertung der Kostenfunktion
J(it+1) = d'*d/(2*m);
end
