%--------------------------------------------------------------------------   
%     Mathematische Modellierung mit MATLAB und Octave, F. Hausser und Y. Luchko
%     Eisausbreitung an der Arktis: Lineares Ausgleichsproblem
%     Listing 6.1
%     Author: Frank Hausser
%     Date:   5/2019
%--------------------------------------------------------------------------

%% Daten einlesen
% ftp://sidads.colorado.edu/DATASETS/NOAA/G02135/north/monthly/data/
data  = csvread('N_09_extent_v3.0.csv',1,4);
years = (1979:2018)';
ti    = years - years(1);
yi    = data(:,1);

%%  lineare Regressionsmodelle 
a1 = @(t) ones(size(t));
a2 = @(t) t;
a3 = @(t) t.*t;

y1 = @(t,x) x(1)*a1(t) + x(2)*a2(t);
A1 = [a1(ti) a2(ti)];
x1 = A1\yi;

y2 = @(t,x) x(1)*a1(t) + x(2)*a2(t) + x(3)*a3(t);
A2 = [a1(ti) a2(ti) a3(ti)];
x2 = A2\yi;

%% Visualisierung 
hold on
% Datenpunkte
plot(years, yi, 'x');   
% Datenfit (Modellfunktion mit optimalen Parametern)
t = linspace(0, ti(end), 500)';
plot(t + years(1), y1(t,x1));
plot(t + years(1), y2(t,x2));