%--------------------------------------------------------------------------   
%     Mathematische Modellierung mit MATLAB und Octave, F. Hausser und Y. Luchko
%     Aidsausbreitung in Brasilien, nichtlineares Ausgleichsproblem
%     Listing 6.3
%     Author: Frank Hausser
%     Date:   5/2019
%--------------------------------------------------------------------------


%% Daten einlesen 
% https://www.ncbi.nlm.nih.gov/pmc/articles/PMC4207789/#pone.0111015
data = csvread('DataAidsBrazil.csv',1,5);
yi   = sum(data,1); % Ueber alle Staedte aufsummiert
ti   = (1980:2012);
t0   = 1980;

%% Berechnung  
%Startvektor bestimmen 
tHalbe  = 16;
steig   = (yi(tHalbe+1)-yi(tHalbe-1))/2;
x0(1,1) = max(yi);
x0(3,1) = 4*steig/x0(1);
x0(2,1) = exp(x0(3)*tHalbe);

% Modellfunktion und Ableitung
y    = @(t, x) x(1)./(1 + x(2)*exp(-x(3)*t));
fun  = @(x) yi' - y(ti-t0, x)'; 
Jfun = @(x) jacLogisticFunction(x, ti-t0); 

% Gauss Newton
tol = 1.e-4; nItMax = 100;
[x, nIt] = gaussNewton(x0, fun, Jfun, tol, nItMax)

%% Visualisierung 
% Daten
plot(ti, yi, 'x'); hold on
% Datenfit (Logistische Funktion)
t = linspace(1980, 2012, 500);
plot(t, y(t-t0, x));
plot(t, y(t-t0, x0));
%legend('Daten', 'Start', 'Fit'); hold off

