%--------------------------------------------------------------------------   
%  Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko
%  
%   Die Funktion sparseMatrixFD3D konstruiert die dnn besetzte
%   Koeffizientenmatrix A aus der Gleichung (6.24) fr das lineare
%   Gleichungssystem (6.23).
%   Diese Funktion benutzt den MATLAB-Befehl sparse, dem die drei
%   zusammengesetzten Vektoren mit den von Null verschiedenen 
%   Matrixelementen sowie den zugehrigen Zeilen- und Spaltennummern 
%   dieser Elemente bergeben werden.
%     Authoren: Peter Otto und Witalij Wambold
%     Date:   1/2010
%
%--------------------------------------------------------------------------

function [ A ] = sparseMatrixFD3D( nx, ny, nz, central_value, x_negative, x_positive, y_negative, y_positive, z_negative, z_positive )

% Bestimmung der Matrix-Dimension
nxy = nx*ny;
dimM = nx*ny*nz;

indDiagX = 1:nx;       
indLowerX = 1:(nx-1);

% Eintrge fr die sparse-Vektoren
dataDiagOfMainBlock  = central_value*ones(nx,1); 
dataLowerOfMainBlock = x_negative*ones(nx-1,1);
dataUpperOfMainBlock = x_positive*ones(nx-1,1); 
dataOfLowerBlock     = y_negative*ones(nx,1); 
dataOfUpperBlock     = y_positive*ones(nx,1); 

lengthMainBlock = nx + 2*(nx-1);
indMainBlock = 1:lengthMainBlock;

lengthSparseXY = ny*lengthMainBlock + 2*nx*(ny-1);

% Preallokation des Speicherplatzes fr die dnn besetzte Matrix A 
rowXY  = zeros(lengthSparseXY,1);
colXY  = zeros(lengthSparseXY,1);
dataXY = zeros(lengthSparseXY,1);

% Zuweisung von Werten an die Elemente in den Sparse-Vektoren
rowXY(indDiagX) = indDiagX;
colXY(indDiagX) = indDiagX;
dataXY(indDiagX) = dataDiagOfMainBlock;
index = nx;

rowXY(index+indLowerX) = indLowerX + 1;
colXY(index+indLowerX) = indLowerX;
dataXY(index+indLowerX) = dataLowerOfMainBlock;
index = index + nx-1;

rowXY(index+indLowerX) = indLowerX;
colXY(index+indLowerX) = indLowerX + 1;
dataXY(index+indLowerX) = dataUpperOfMainBlock;
index = index + nx-1;

for k=1:ny-1
    rowXY(index+indMainBlock)  = rowXY(indMainBlock) + k*nx;
    colXY(index+indMainBlock)  = colXY(indMainBlock) + k*nx;
    dataXY(index+indMainBlock) = dataXY(indMainBlock);
    index = index + lengthMainBlock;
    
    rowXY(index+indDiagX)  = k*nx + indDiagX;
    colXY(index+indDiagX)  = (k-1)*nx + indDiagX;
    dataXY(index+indDiagX) = dataOfLowerBlock;
    index = index + nx;
    
    rowXY(index+indDiagX)  = (k-1)*nx + indDiagX;
    colXY(index+indDiagX)  = k*nx + indDiagX;
    dataXY(index+indDiagX) = dataOfUpperBlock;
    index = index + nx;
end

dataWithZ = repmat(dataXY,nz,1);

rowWithZ = zeros(lengthSparseXY*nz,1);
colWithZ = zeros(lengthSparseXY*nz,1);

for i=0:(nz-1)
    rowWithZ(i*lengthSparseXY + (1:lengthSparseXY)) = rowXY + i*nxy;
    colWithZ(i*lengthSparseXY + (1:lengthSparseXY)) = colXY + i*nxy;
end

lengthOfZDiag = dimM - nxy;

colZnegative = (1:lengthOfZDiag)';
rowZnegative = nxy + colZnegative;
dataZnegative = z_negative*ones(lengthOfZDiag,1);

colZpositive = rowZnegative;
rowZpositive = colZnegative;
dataZpositive = z_positive*ones(lengthOfZDiag,1);

rowWithZ = [rowWithZ;rowZnegative;rowZpositive];
colWithZ = [colWithZ;colZnegative;colZpositive];
dataWithZ = [dataWithZ;dataZnegative;dataZpositive];

lengthOfSparseMatrix = nz*lengthSparseXY + 2*lengthOfZDiag;

% Konstruktion der Matrix A aus den sparse-Vektoren 
A = sparse(rowWithZ, colWithZ, dataWithZ, dimM, dimM, lengthOfSparseMatrix);

end

