%--------------------------------------------------------------------------
%  Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko
%  Kapitel 8, Abbildung 8.2:
%       Lsung der logistischen Gleichung 
%       fr $0 < n_0 < 1$  und  fr $n_0 > 1$. 
%
%     Author: Yury Luchko
%     Date:   3/2010
%--------------------------------------------------------------------------
clear
% Numerische Loesung der logistischen DGL
% Zeitintervall
T=15.0;
% 1. Fall: Anfangsbedingung ist kleiner als 1
n0 = 0.01;
% Rechte Seite der DGL
func=@(t,n) (n(1)*(1-n(1)));
% Numerische Loesung der DGL mit dem Solver ode45
[t,n] = ode45(func,[0 T],n0);
% Visualisierung der Ergebnisse auf dem Zeitintervall [0,T]
subplot(1,2,1)
plot(t,n(:),'k','linewidth',2)
ylabel('n(\tau)')
xlabel('\tau')

% 2. Fall: Anfangsbedingung ist groesser als 1
% Zeitintervall
T=10.0;
% Anfangsbedingung 
n0 = 1.5;
% Numerische Loesung der DGL mit dem ode45 Solver
[t,n] = ode45(func,[0 T],n0);
% Visualisierung der Ergebnisse auf dem Zeitintervall [0,T]
subplot(1,2,2)
plot(t,n(:),'k','linewidth',2)
ylabel('n(\tau)')
xlabel('\tau')