%--------------------------------------------------------------------------
%  Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko
%  Kapitel 8, Abbildung 8.4:
%       Zeitliche Entwicklung der Fischbestnde mit Anfangswerten 
%       $n_0 = 0.25$ und $n_0 = 1$ nach dem Modell (8.11). 
%       Die relative Fangquote ist  $p = 0.5$. 
%
%     Author: Yury Luchko
%     Date:   3/2010
%--------------------------------------------------------------------------

clear
% Systemparameter:
% Laenge des Zeitintervalls
L=8.0;
% optimale relative Fanquote 
p = 0.5;
% Gleichgewichtlsung
x = 0:0.1:L;
y = 0:0.1:L;
y(:)=1-p;
plot(x,y,'--','Color','k','linewidth',2);
hold on;
legend('Gleichgewichtslsung n_2=1-p');
% Rechte Seite der DGL
func = @(t,n) (n(1)*(1-n(1))-0.5*n(1));
options = odeset('AbsTol',1.e-8,'RelTol',1.e-4,'Refine',20);
% 1. Anfangsbedingung (groesser als die Gleichgewichtsloesung)
n0 = 1;
% Numerische Lsung der DGL
[t,n] = ode45(func,[0 L],n0,options);
plot(t,n(:),'k','linewidth',2)
% 2. Anfangsbedingung (kleiner als die Gleichgewichtsloesung)
n0 = (1-p)/2;
% Numerische Lsung der DGL
[t,n] = ode45(func,[0 L],n0,options);
plot(t,n(:),'k','linewidth',2)
ylabel('n(t)')
xlabel('t')
hold off;