%--------------------------------------------------------------------------
%  Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko
%  Kapitel 8, Abbildung 8.5:
%       Periodische Lsungen des Lotka-Volterra-Modells: Geschlossene
%       Kurven im Phasenraum fr drei unterschiedliche Parameterstze 
%       $\rho = 0.4,\ 0.5,\ 0.7$ und periodische Entwicklung der Ruber 
%       und der Beutepopulation ber der Zeit fr $\rho = 0.7$ 
%
%     Author: Yury Luchko
%     Date:   3/2010
%--------------------------------------------------------------------------

clear
% 1. Fall (Modellparameter, Anfangsbedingungen, Zeitintervall)
rho = 0.4; x0 =[0.6 0.4]'; tspan=[0,30]; 
% Rechte Seite der DGL 
func = @(t,x) [rho*x(1)*(1-x(2)); -x(2)*(1-x(1))/rho];
options = odeset('AbsTol',1.e-8,'RelTol',1.e-4,'Refine',20);
% Numerische Lsung der DGL
[t,x]=ode45(func,tspan,x0,options); 
% Plotten der Ergebnisse im Phasenraum
subplot(1,2,1)
plot(x(:,1),x(:,2),'k','linewidth',2)
axis([0,3,0,5])
ylabel('x_2(t)')
xlabel('x_1(t)')
hold on
% 2. Fall:
rho = 0.5; x0 =[0.4 0.3]'; tspan=[0,30]; 
% Rechte Seite der DGL 
func1 = @(t,x) [rho*x(1)*(1-x(2)); -x(2)*(1-x(1))/rho];
% Nmerische Lsung der DGL
[t,x]=ode45(func1,tspan,x0,options); 
% Plotten der Ergebnisse im Phasenraum
plot(x(:,1),x(:,2),'k','linewidth',2)
% 3. Fall:
rho = 0.7; x0 =[0.4 0.3]'; tspan=[0,30]; 
% Rechte Seite der DGL 
func2 = @(t,x) [rho*x(1)*(1-x(2)); -x(2)*(1-x(1))/rho];
% Numerische Lsung der DGL
[t,x]=ode45(func2,tspan,x0,options); 
% Plotten der Ergebnisse im Phasenraum
plot(x(:,1),x(:,2),'k','linewidth',2)
hold off;
subplot(1,2,2)
% Plotten der Ergebnisse im Koordinatenraum
plot(t,x(:,1),'k','linewidth',2)
hold on;
plot(t,x(:,2),'--','Color','k','linewidth',2)
legend('x_1(t)','x_2(t)');
ylabel('x(t)')
xlabel('t')
hold off