%--------------------------------------------------------------------------
%  Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko
%  Kapitel 8, Abbildung 8.6:
%       Phasenraumtrajektorie einer Lsung des Gleichungssystems
%       (8.16) mit $k < k_0 = 2 +\beta$ und einer Lsung 
%       mit $k > k_0 = 2 +\beta$
%
%     Author: Yury Luchko
%     Date:   3/2010
%--------------------------------------------------------------------------
clear

% 1. Fall ($k < k_0 = 2 +\beta$):
% Anfangsbedingungen, Zeitintervall
x0 =[0.5 1.0]'; tspan=[0,50]; 
% Parameterwerte
beta = 5.2; gamma = 2.7; k = (2+beta)/4;
a1 = (1 - 1/k)*(1+beta); a2 = gamma*(1+beta);
% Rechte Seite der DGL
func = @(t,x) [x(1)*(1-x(1)/k) - (a1*x(1)*x(2))/(beta + x(1)); ...
    -gamma*x(2)+(a2*x(1)*x(2))/(beta + x(1))];
% Numerische Lsung der DGL
options = odeset('AbsTol',1.e-8,'RelTol',1.e-4,'Refine',20);
[t,x]=ode45(func,tspan,x0,options); 
% Plotten der Ergebnisse im Phasenraum
subplot(1,2,1)
plot(x(:,1),x(:,2),'k','linewidth',2)
hold on
ylabel('x_2(t)')
xlabel('x_1(t)')

% 2. Fall ($k > k_0 = 2 +\beta$)
% Anfangsbedingungen, Zeitintervall
x0 =[0.5 1.0]'; tspan=[0,50]; 
% Parameterwerte
beta = 5.2; gamma = 2.7; k = (2+beta)+2; 
a1 = (1 - 1/k)*(1+beta); a2 = gamma*(1+beta);
% Rechte Seite der DGL
func1 = @(t,x) [x(1)*(1-x(1)/k) - (a1*x(1)*x(2))/(beta + x(1));...
    -gamma*x(2)+ (a2*x(1)*x(2))/(beta + x(1))];
% Lsen der DGL 
[T,x]=ode45(func1,tspan,x0,options); 
% Plotten der Ergebnisse im Phasenraum
subplot(1,2,2)
plot(x(:,1),x(:,2),'k','linewidth',2)
ylabel('x_2(t)')
xlabel('x_1(t)')
hold off;

