%--------------------------------------------------------------------------   
%  Mathematische Modellierung mit MATLAB, F. Hausser und Y. Luchko
%  
%  Schadstoffausbreitung mit einer sinusfrmigen Anfangsbedingung und mit
%  starkem Abbau (v/alpha = 1 << 10 = L)
%           Abbildung 9.2
%     Author: Yury Luchko
%     Date:   2/2010
%
%--------------------------------------------------------------------------

clear;
% System- und Verfahrensparameter
L = 10.0;  T = 40.; K = 50; n = 50;
dt = T/K;  dx = L/n;
v =.1; alpha = .1;  
% Speicherallozierung und Gitterpunkte
x = linspace(0,L,n+1);
time = linspace(0,T,K+1);
u = zeros(n+1, K+1);
% Anfangsbedingung
u(:,1) = sin(pi*x(:)/2)+1.0;
% Randbedingung 
u(1,:) = 1.0;
% Konstruktion der Koeffizientenmatrix B
e = - v*dt/dx; f  = 1 + v*dt/dx + dt*alpha; 
B = gallery('tridiag',n,e,f,0);
% Konstruktion der rechten Seite c_k
% und Lsung des Systems fr alle Zeitschritte
for k = 1:K
    c(1) = -e*u(1, k+1) + u(2, k); 
    c(2:n) = u(3:n+1, k); 
    z = B\c';
    u(2:n+1, k+1) = z';
end
% Visualisierung der Ergebnisse
mesh(x,time,u')
xlabel('x');
ylabel('t');
zlabel('u(x,t)');

